==> openshift-serverless-logic-1.26.0-src.zip: openshift-serverless-logic-1.26.0.GA-src/org.kie.kogito-kogito-apps-1.30.0.Final/ui-packages/packages/custom-dashboard-list/src/envelope/CustomDashboardListEnvelopeView.tsx <==
/*
 * Copyright 2022 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import React, { useImperativeHandle, useState } from 'react';
import { MessageBusClientApi } from '@kogito-tooling/envelope-bus/dist/api';
import { CustomDashboardListChannelApi } from '../api';
import CustomDashboardList from './components/CustomDashboardList/CustomDashboardList';
import CustomDashboardListEnvelopeViewDriver from './CustomDashboardListEnvelopeViewDriver';
import '@patternfly/patternfly/patternfly.css';

export interface CustomDashboardListEnvelopeViewApi {
  initialize: () => void;
}

interface Props {
  channelApi: MessageBusClientApi<CustomDashboardListChannelApi>;
}

export const CustomDashboardListEnvelopeView = React.forwardRef<
  CustomDashboardListEnvelopeViewApi,
  Props
>((props, forwardedRef) => {
  const [
    isEnvelopeConnectedToChannel,
    setEnvelopeConnectedToChannel
  ] = useState<boolean>(false);
  useImperativeHandle(
    forwardedRef,
    () => ({
      initialize: () => {
        setEnvelopeConnectedToChannel(true);
      }
    }),
    []
  );

  return (
    <React.Fragment>
      <CustomDashboardList
        isEnvelopeConnectedToChannel={isEnvelopeConnectedToChannel}
        driver={new CustomDashboardListEnvelopeViewDriver(props.channelApi)}
      />
    </React.Fragment>
  );
});

export default CustomDashboardListEnvelopeView;

==> openshift-serverless-logic-1.28.0-src.zip: openshift-serverless-logic-1.28.0.GA-src/org.kie.kogito-kogito-apps-1.35.0.Final/ui-packages/packages/custom-dashboard-list/src/envelope/CustomDashboardListEnvelopeView.tsx <==
/*
 * Copyright 2022 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import React, { useImperativeHandle, useState } from 'react';
import { MessageBusClientApi } from '@kogito-tooling/envelope-bus/dist/api';
import { CustomDashboardListChannelApi } from '../api';
import CustomDashboardList from './components/CustomDashboardList/CustomDashboardList';
import CustomDashboardListEnvelopeViewDriver from './CustomDashboardListEnvelopeViewDriver';
import '@patternfly/patternfly/patternfly.css';

export interface CustomDashboardListEnvelopeViewApi {
  initialize: () => void;
}

interface Props {
  channelApi: MessageBusClientApi<CustomDashboardListChannelApi>;
}

export const CustomDashboardListEnvelopeView = React.forwardRef<
  CustomDashboardListEnvelopeViewApi,
  Props
>((props, forwardedRef) => {
  const [isEnvelopeConnectedToChannel, setEnvelopeConnectedToChannel] =
    useState<boolean>(false);
  useImperativeHandle(
    forwardedRef,
    () => ({
      initialize: () => {
        setEnvelopeConnectedToChannel(true);
      }
    }),
    []
  );

  return (
    <React.Fragment>
      <CustomDashboardList
        isEnvelopeConnectedToChannel={isEnvelopeConnectedToChannel}
        driver={new CustomDashboardListEnvelopeViewDriver(props.channelApi)}
      />
    </React.Fragment>
  );
});

export default CustomDashboardListEnvelopeView;
